let questions = [
    {
        prompt: `Which activity has the smallest carbon footprint?`,
        options: [
            "Flying across the country",
            "Driving solo for a long road trip",
            "Taking a train for a long-distance journey",
            "Using a bus for intercity travel",
        ],
        answer: "Taking a train for a long-distance journey",
    },
    {
        prompt: `What percentage of global carbon emissions is contributed by the tourism industry?`,
        options: [
            " 2%",
            " 5%",
            " 8%",
            " 12%",
        ],
        answer: " 8%",
    },
    {
        prompt: `Which of the following is considered an eco-friendly accommodation option?`,
        options: [
            "A luxury hotel with many amenities",
            "A traditional bed and breakfast",
            "A certified green hotel with sustainable practices",
            "A budget motel",
        ],
        answer: "A certified green hotel with sustainable practices",
    },
];

// Get DOM Elements
let questionsEl = document.querySelector("#questions");
let timerEl = document.querySelector("#timer");
let choicesEl = document.querySelector("#options");
let startBtn = document.querySelector("#start");
let endMessageEl = document.querySelector("#end-message");
let finalInputsEl = document.querySelector("#final-inputs");

// Quiz's initial state
let currentQuestionIndex = 0;
let time = 60; // Set timer for 1 minute
let timerId;
let score = 0;

// Start quiz and hide front page
function quizStart() {
    timerId = setInterval(clockTick, 1000);
    timerEl.textContent = formatTime(time);
    let landingScreenEl = document.getElementById("start-screen");
    landingScreenEl.setAttribute("class", "hide");
    questionsEl.removeAttribute("class");
    getQuestion();
}

// Loop through array of questions and answers and create list with buttons
function getQuestion() {
    let currentQuestion = questions[currentQuestionIndex];
    let promptEl = document.getElementById("question-words");
    promptEl.textContent = currentQuestion.prompt;
    choicesEl.innerHTML = "";
    currentQuestion.options.forEach(function (choice, i) {
        let choiceBtn = document.createElement("button");
        choiceBtn.setAttribute("value", choice);
        choiceBtn.textContent = i + 1 + ". " + choice;
        choiceBtn.onclick = questionClick;
        choicesEl.appendChild(choiceBtn);
    });
}

// Check for right answers, update score, and go to the next question or end quiz
function questionClick() {
    let selectedAnswer = this.value;
    let correctAnswer = questions[currentQuestionIndex].answer;

    if (selectedAnswer === correctAnswer) {
        score += 1; // Add 1 point for each correct answer
    } else {
        // Change the correct answer button to red
        let buttons = document.querySelectorAll("#options button");
        buttons.forEach(button => {
            if (button.value === correctAnswer) {
                button.style.backgroundColor = "red";
            }
        });
    }

    setTimeout(() => {
        currentQuestionIndex++;
        if (currentQuestionIndex === questions.length) {
            quizEnd();
        } else {
            getQuestion();
        }
    }, 1000); // Wait 2 seconds before moving to the next question
}

// End quiz by hiding questions, stop timer, and show final score
function quizEnd() {
    clearInterval(timerId);
    let endScreenEl = document.getElementById("quiz-end");
    endScreenEl.removeAttribute("class");
    let finalScoreEl = document.getElementById("score-final");
    finalScoreEl.textContent = `${score}/3`; // Display the total score as x/3
    questionsEl.setAttribute("class", "hide");

    if (score === questions.length) {
        // Show the email and name entry form if the user gets all the questions correct
        endMessageEl.innerHTML = `<span class="green-text">Woohoo, Eco-Mastermind!<br></span> You’ve unlocked the secrets of sustainability and bagged 1000 Green Points! <br 
        Your eco-savvy skills are making waves. Keep up the fantastic work.`;
        finalInputsEl.removeAttribute("class");
    } else {
        // Show a "Try Again" message with specified text formatting
        endMessageEl.innerHTML = `
            <span style="color: green; font-weight: bold; font-size: 24px;">Nice Try, Eco-Explorer!</span>  <br/><br/>
            <span style="color: black; font-size: 16px;">You’re on the right path to sustainability, but there’s still a bit more to uncover. Don't worry, every step counts! Keep learning and try again – the planet is counting on you!</span>
        `;
    }

    // Update the hidden score field in the form
    document.getElementById("user-score").value = `${score}/3`;
}

// Timer function to handle the countdown
function clockTick() {
    time--;
    timerEl.textContent = formatTime(time);
    if (time <= 0) {
        quizEnd();
    }
}

// Format time in minutes and seconds
function formatTime(seconds) {
    let minutes = Math.floor(seconds / 60);
    let secs = seconds % 60;
    return `${minutes}:${secs < 10 ? "0" : ""}${secs}`;
}

// Start quiz after clicking start quiz
startBtn.onclick = quizStart;
